# [PywAI](https://github.com/emptor/pywai) • Python AI wrapper for the WhatsApp Cloud API

________________________

**PywAI is a simple asynchronous framework (based on PyWA) to enable the creation of AI agents and bots on Whatsapp.**

📄 **Quick Documentation Index**
--------------------------------

*TODO*

------------------------

⚡ **Features**
---------------
- 🚀 Fast and simple to use. No need to worry about the low-level details.
- Use OpenAI to generate responses
- Rewrite long responses to be more conversational
- Save conversation history on a local SQLite (encrypted or not)

------------------------

👨‍💻 **Usage**
----------------

*TODO*

🎛 **Installation**
--------------------

*TODO*

💾 **Requirements**
--------------------

- Python 3.10 or higher - https://www.python.org

📖 **Setup and Usage**
-----------------------

*TODO*

☑️ **TODO**
------------

- Public docs
- Sync with pywa 2.0
- Add more examples and guides

Feel free to open an issue if you have any suggestions. or even better - submit a PR!

⚖️ **License**
---------------

This project is licensed under the MIT License - see the
[LICENSE](https://github.com/emptor/pywai/blob/master/LICENSE) file for details


🔱 **Contributing**
--------------------

Contributions are welcome! Please feel free to submit a Pull Request.
